==> kmymoney-5.1.95.tar.xz: kmymoney-5.1.95/kmymoney/plugins/sql/sqlstorage.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "tonybloom@users.sourceforge.net,lukasz.wojnilowicz@gmail.com",
                "Name": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[ca@valencia]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[ca]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[de]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[en_GB]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[eo]": "Tony Bloomfield, Łukasz Wojniłowicz",
                "Name[es]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[et]": "Tony Bloomfield, Łukasz Wojniłowicz",
                "Name[eu]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[fi]": "Tony Bloomfield, Łukasz Wojniłowicz",
                "Name[fr]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[gl]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[ia]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[it]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[ka]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[ko]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[nb]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[nl]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[pl]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[pt]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[pt_BR]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[ru]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[sk]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[sl]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[sv]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[tr]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[uk]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[x-test]": "xxTony Bloomfield,Łukasz Wojniłowiczxx",
                "Name[zh_CN]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[zh_TW]": "Tony Bloomfield、Łukasz Wojniłowicz"
            }
        ],
        "Description": "Adds SQL storage support to KMyMoney",
        "Description[ca@valencia]": "Afig la implementació de l'emmagatzematge en SQL a KMyMoney",
        "Description[ca]": "Afegeix la implementació de l'emmagatzematge en SQL al KMyMoney",
        "Description[en_GB]": "Adds SQL storage support to KMyMoney",
        "Description[eo]": "Aldonas SQL-stokan subtenon al KMyMoney",
        "Description[es]": "Añade almacenamiento SQL a KMyMoney",
        "Description[et]": "KMyMoney SQL-salvesti toetus",
        "Description[eu]": "SQL biltegiratze euskarria gehitzen dio KMyMoneyri",
        "Description[fi]": "Lisää KMyMoneyyn SQL-varastotuen",
        "Description[fr]": "Ajoute la prise en charge du stockage « SQL » à KMyMoney",
        "Description[gl]": "Engade a posibilidade de almacenamento de SQL en KMyMoney",
        "Description[it]": "Aggiunge il supporto di archiviazione a KMyMoney",
        "Description[ka]": "KMyMoney-ში SQL საცავის მხარდაჭერის დამატება",
        "Description[ko]": "KMyMoney에 SQL 저장소 지원 추가",
        "Description[nb]": "Legger til støtte for SQL-lagring i KMyMoney",
        "Description[nl]": "Voegt ondersteuning toe voor SQL-opslag aan KMyMoney",
        "Description[pl]": "Dodaje obsługę pamięci SQL do KMyMoney",
        "Description[pt]": "Adiciona o suporte do armazenamento em SQL ao KMyMoney",
        "Description[pt_BR]": "Adiciona suporte ao armazenamento SQL no KMyMoney",
        "Description[ru]": "Добавляет в KMyMoney поддержку хранения данных в формате SQL",
        "Description[sk]": "Pridáva podporu SQL úložiska do KMyMoney",
        "Description[sl]": "Doda v KMyMoney podporo za shranjevanje SQL",
        "Description[sv]": "Lägger till stöd för SQL-lagring i KMyMoney",
        "Description[tr]": "K Param'a SQL depolama desteği ekler",
        "Description[uk]": "Підтримка сховища даних SQL у KMyMoney",
        "Description[x-test]": "xxAdds SQL storage support to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加 SQL 存储支持",
        "Description[zh_TW]": "提供 SQL 儲存功能給 KMyMoney",
        "EnabledByDefault": true,
        "Icon": "server-database",
        "Id": "sqlstorage",
        "License": "GPL",
        "Name": "SQL Storage",
        "Name[ca@valencia]": "Emmagatzematge SQL",
        "Name[ca]": "Emmagatzematge SQL",
        "Name[cs]": "Úložiště SQL",
        "Name[de]": "SQL-Speicher",
        "Name[en_GB]": "SQL Storage",
        "Name[eo]": "SQL-Konservado",
        "Name[es]": "Almacenamiento SQL",
        "Name[et]": "SQL-salvesti",
        "Name[eu]": "SQL biltegiratzea",
        "Name[fi]": "SQL-varasto",
        "Name[fr]": "Stockage SQL",
        "Name[gl]": "Almacenamento de SQL",
        "Name[it]": "Archiviazione SQL",
        "Name[ka]": "SQL საცავი",
        "Name[ko]": "SQL 저장소",
        "Name[nb]": "SQL-lagring",
        "Name[nl]": "SQL-opslag",
        "Name[pl]": "Pamięć SQL",
        "Name[pt]": "Armazenamento em SQL",
        "Name[pt_BR]": "Armazenamento SQL",
        "Name[ru]": "Сохранение SQL",
        "Name[sk]": "SQL Úložisko",
        "Name[sl]": "Shramba SQL",
        "Name[sv]": "SQL-lagring",
        "Name[tr]": "SQL Depolama",
        "Name[uk]": "Сховище SQL",
        "Name[x-test]": "xxSQL Storagexx",
        "Name[zh_CN]": "SQL 存储",
        "Name[zh_TW]": "SQL 儲存",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney-5.2.0.tar.xz: kmymoney-5.2.0/kmymoney/plugins/sql/sqlstorage.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "tonybloom@users.sourceforge.net,lukasz.wojnilowicz@gmail.com",
                "Name": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[ca@valencia]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[ca]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[de]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[en_GB]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[eo]": "Tony Bloomfield, Łukasz Wojniłowicz",
                "Name[es]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[et]": "Tony Bloomfield, Łukasz Wojniłowicz",
                "Name[eu]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[fi]": "Tony Bloomfield, Łukasz Wojniłowicz",
                "Name[fr]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[gl]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[ia]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[it]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[ka]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[ko]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[nb]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[nl]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[pl]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[pt]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[pt_BR]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[ru]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[sk]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[sl]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[sv]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[uk]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[x-test]": "xxTony Bloomfield,Łukasz Wojniłowiczxx",
                "Name[zh_CN]": "Tony Bloomfield,Łukasz Wojniłowicz",
                "Name[zh_TW]": "Tony Bloomfield、Łukasz Wojniłowicz"
            }
        ],
        "Description": "Adds SQL storage support to KMyMoney",
        "Description[ca@valencia]": "Afig la implementació de l'emmagatzematge en SQL a KMyMoney",
        "Description[ca]": "Afegeix la implementació de l'emmagatzematge en SQL al KMyMoney",
        "Description[en_GB]": "Adds SQL storage support to KMyMoney",
        "Description[eo]": "Aldonas SQL-stokan subtenon al KMyMoney",
        "Description[es]": "Añade almacenamiento SQL a KMyMoney",
        "Description[et]": "KMyMoney SQL-salvesti toetus",
        "Description[eu]": "SQL biltegiratze euskarria gehitzen dio KMyMoneyri",
        "Description[fi]": "Lisää KMyMoneyyn SQL-varastotuen",
        "Description[fr]": "Ajoute la prise en charge du stockage « SQL » à KMyMoney",
        "Description[gl]": "Engade a posibilidade de almacenamento de SQL en KMyMoney",
        "Description[ia]": "Adde supporto de immagazinage de SQL a KMyMoney",
        "Description[it]": "Aggiunge il supporto di archiviazione a KMyMoney",
        "Description[ka]": "KMyMoney-ში SQL საცავის მხარდაჭერის დამატება",
        "Description[ko]": "KMyMoney에 SQL 저장소 지원 추가",
        "Description[nb]": "Legger til støtte for SQL-lagring i KMyMoney",
        "Description[nl]": "Voegt ondersteuning toe voor SQL-opslag aan KMyMoney",
        "Description[pl]": "Dodaje obsługę pamięci SQL do KMyMoney",
        "Description[pt]": "Adiciona o suporte do armazenamento em SQL ao KMyMoney",
        "Description[pt_BR]": "Adiciona suporte ao armazenamento SQL no KMyMoney",
        "Description[ru]": "Добавляет в KMyMoney поддержку хранения данных в формате SQL",
        "Description[sk]": "Pridáva podporu SQL úložiska do KMyMoney",
        "Description[sl]": "Doda v KMyMoney podporo za shranjevanje SQL",
        "Description[sv]": "Lägger till stöd för SQL-lagring i KMyMoney",
        "Description[uk]": "Підтримка сховища даних SQL у KMyMoney",
        "Description[x-test]": "xxAdds SQL storage support to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加 SQL 存储支持",
        "Description[zh_TW]": "提供 SQL 儲存功能給 KMyMoney",
        "EnabledByDefault": true,
        "Icon": "server-database",
        "Id": "sqlstorage",
        "License": "GPL",
        "Name": "SQL Storage",
        "Name[ca@valencia]": "Emmagatzematge SQL",
        "Name[ca]": "Emmagatzematge SQL",
        "Name[cs]": "Úložiště SQL",
        "Name[de]": "SQL-Speicher",
        "Name[en_GB]": "SQL Storage",
        "Name[eo]": "SQL-Konservado",
        "Name[es]": "Almacenamiento SQL",
        "Name[et]": "SQL-salvesti",
        "Name[eu]": "SQL biltegiratzea",
        "Name[fi]": "SQL-varasto",
        "Name[fr]": "Stockage SQL",
        "Name[gl]": "Almacenamento de SQL",
        "Name[ia]": "Immagazinage SQL",
        "Name[it]": "Archiviazione SQL",
        "Name[ka]": "SQL საცავი",
        "Name[ko]": "SQL 저장소",
        "Name[nb]": "SQL-lagring",
        "Name[nl]": "SQL-opslag",
        "Name[pl]": "Pamięć SQL",
        "Name[pt]": "Armazenamento em SQL",
        "Name[pt_BR]": "Armazenamento SQL",
        "Name[ru]": "Сохранение SQL",
        "Name[sk]": "SQL Úložisko",
        "Name[sl]": "Shramba SQL",
        "Name[sv]": "SQL-lagring",
        "Name[uk]": "Сховище SQL",
        "Name[x-test]": "xxSQL Storagexx",
        "Name[zh_CN]": "SQL 存储",
        "Name[zh_TW]": "SQL 儲存",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
